FillRule

Enum FillRule 

pub enum FillRule {
    NonZero,
    EvenOdd,
}
Represents the fill rule used for determining the interior of shapes.

Corresponds to the SVG fill-rule attribute and is used in polygon(), path(), and shape() functions.

Variants



NonZero

The default rule - counts the number of times a ray from the point crosses the shape’s edges



EvenOdd

Counts the total number of crossings - if even, the point is outside