#[non_exhaustive]pub enum FlexDirection {
Row,
Column,
RowReverse,
ColumnReverse,
}Expand description
Defines the direction of flex items within a flex container.
This enum determines how flex items are laid out along the main axis.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Row
Items are laid out in the same direction as the text direction (left-to-right for English)
Column
Items are laid out perpendicular to the text direction (top-to-bottom)
RowReverse
Items are laid out in the opposite direction to the text direction (right-to-left for English)
ColumnReverse
Items are laid out opposite to the column direction (bottom-to-top)