#[non_exhaustive]pub enum GridDirection {
Row,
Column,
}Expand description
Represents the direction of the grid auto flow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Row
The grid auto flow is in the row direction.
Column
The grid auto flow is in the column direction.