#[non_exhaustive]pub enum GridLength {
Fr(f32),
Unit(Length),
}Expand description
Represents a grid track sizing function with serde support
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl GridLength
impl GridLength
Sourcepub fn to_compact_length(self, sizing: &SizingContext) -> CompactLength
pub fn to_compact_length(self, sizing: &SizingContext) -> CompactLength
Converts the grid track size to a compact length representation.