#[non_exhaustive]pub enum GridRepetitionKeyword {
AutoFill,
AutoFit,
}Expand description
Represents grid track repetition keywords
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AutoFill
Automatically fills the available space with as many tracks as possible
AutoFit
Automatically fits as many tracks as possible while maintaining minimum size