#[non_exhaustive]pub enum GridTemplateComponent {
LineNames(Vec<String>),
Single(GridTrackSize),
Repeat(GridRepetitionCount, Vec<GridRepeatTrack>),
}Expand description
Represents a track sizing function or a list of line names between tracks
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LineNames(Vec<String>)
A list of line names that apply to the current grid line (e.g., [a b])
Single(GridTrackSize)
A single non-repeated track
Repeat(GridRepetitionCount, Vec<GridRepeatTrack>)
Automatically generate grid tracks to fit the available space using the specified definite track lengths Only valid if every track in template (not just the repetition) has a fixed size.