ImageScalingAlgorithm

Enum ImageScalingAlgorithm 

pub enum ImageScalingAlgorithm {
    Auto,
    Smooth,
    Pixelated,
}
Defines how images should be scaled when rendered.

Variants



Auto

The image is scaled using Catmull-Rom interpolation. This is balanced for speed and quality.



Smooth

The image is scaled using Lanczos3 resampling. This provides high-quality scaling but may be slower.



Pixelated

The image is scaled using nearest neighbor interpolation, which is suitable for pixel art or images where sharp edges are desired.