JustifyContent

Enum JustifyContent 

#[non_exhaustive]
pub enum JustifyContent {
Show 15 variants Normal, Start, End, FlexStart, FlexEnd, Center, Stretch, SpaceBetween, SpaceEvenly, SpaceAround, SafeStart, SafeEnd, SafeFlexStart, SafeFlexEnd, SafeCenter,
}
Defines how flex items are aligned along the main axis.

This enum determines how space is distributed between and around flex items along the main axis of the flex container.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Normal

The items are distributed using the normal flow of the flex container.



Start

Items are packed toward the start of the line.



End

Items are packed toward the end of the line.



FlexStart

Items are packed toward the flex container’s main-start side. For flex containers with flex_direction RowReverse or ColumnReverse, this is equivalent to End. In all other cases it is equivalent to Start.



FlexEnd

Items are packed toward the flex container’s main-end side. For flex containers with flex_direction RowReverse or ColumnReverse, this is equivalent to Start. In all other cases it is equivalent to End.



Center

Items are packed toward the center of the line.



Stretch

Items are stretched to fill the container (only applies to flex containers)



SpaceBetween

Items are evenly distributed in the line; first item is on the start line, last item on the end line.



SpaceEvenly

Items are evenly distributed in the line with equal space around them.



SpaceAround

Items are evenly distributed in the line; first item is on the start line, last item on the end line, and the space between items is twice the space between the start/end items and the container edges.



SafeStart

safe start: like Start, falling back to start-edge alignment on overflow.



SafeEnd

safe end: like End, falling back to start-edge alignment on overflow.



SafeFlexStart

safe flex-start: like FlexStart, falling back to start-edge alignment on overflow.



SafeFlexEnd

safe flex-end: like FlexEnd, falling back to start-edge alignment on overflow.



SafeCenter

safe center: like Center, falling back to start-edge alignment on overflow.