Length

Enum Length 

#[non_exhaustive]
pub enum Length<const DEFAULT_AUTO: bool = true> {
Show 22 variants Auto, Percentage(f32), Rem(f32), Em(f32), Lh(f32), Rlh(f32), Vh(f32), Vw(f32), CqH(f32), CqW(f32), CqMin(f32), CqMax(f32), VMin(f32), VMax(f32), Cm(f32), Mm(f32), In(f32), Q(f32), Pt(f32), Pc(f32), Px(f32), Calc(CalcFormula),
}
Represents a value that can be a specific length, percentage, or automatic.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Auto

Automatic sizing based on content



Percentage(f32)

Percentage value relative to parent container (0-100)



Rem(f32)

Rem value relative to the root font size



Em(f32)

Em value relative to the font size



Lh(f32)

Lh value relative to the element’s computed line-height



Rlh(f32)

Rlh value relative to the root element’s computed line-height



Vh(f32)

Vh value relative to the viewport height (0-100)



Vw(f32)

Vw value relative to the viewport width (0-100)



CqH(f32)

Cqh value relative to the query container height (0-100)



CqW(f32)

Cqw value relative to the query container width (0-100)



CqMin(f32)

Cqmin value relative to the query container smaller dimension (0-100)



CqMax(f32)

Cqmax value relative to the query container larger dimension (0-100)



VMin(f32)

Vmin value relative to the smaller viewport dimension (0-100)



VMax(f32)

Vmax value relative to the larger viewport dimension (0-100)



Cm(f32)

Centimeter value



Mm(f32)

Millimeter value



In(f32)

Inch value



Q(f32)

Quarter value



Pt(f32)

Point value



Pc(f32)

Picas value



Px(f32)

Specific pixel value



Calc(CalcFormula)

calc(…) expression

Implementations

Source

impl<const DEFAULT_AUTO: bool> Length<DEFAULT_AUTO>

pub fn from_spacing(units: f32) -> Self

Construct a length from a Tailwind spacing-scale multiplier.

Source

impl<const DEFAULT_AUTO: bool> Length<DEFAULT_AUTO>

pub const fn zero() -> Self

Returns a zero pixel length unit.

pub fn try_negative(self) -> Option<Self>

Negated value, or None for non-negatable forms like auto.

pub fn negative(self) -> Self

Returns a negative length unit.

Source

impl<const DEFAULT_AUTO: bool> Length<DEFAULT_AUTO>