pub enum ObjectFit {
Fill,
Contain,
Cover,
ScaleDown,
None,
}Expand description
Defines how an image should be resized to fit its container.
Similar to CSS object-fit property.
Variants
Fill
The replaced content is sized to fill the element’s content box exactly, without maintaining aspect ratio
Contain
The replaced content is scaled to maintain its aspect ratio while fitting within the element’s content box
Cover
The replaced content is sized to maintain its aspect ratio while filling the element’s entire content box
ScaleDown
The content is sized as if none or contain were specified, whichever would result in a smaller concrete object size
None
The replaced content is not resized and maintains its intrinsic dimensions