#[non_exhaustive]pub enum TextFitTarget {
Consistent,
PerLine,
PerLineAll,
}Expand description
Text fitting scale target.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Consistent
Use one scale for all lines.
PerLine
Use a separate scale for each line except the last.
PerLineAll
Use a separate scale for each line including the last.