#[non_exhaustive]pub enum TextOverflow {
Clip,
Ellipsis,
Custom(String),
}Expand description
Defines how text should be overflowed.
This enum determines how text should be handled when it exceeds the container width.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Clip
Text is simply clipped at the overflow edge with no visual indication
Ellipsis
Text is truncated with an ellipsis (…) at the end when it overflows
Custom(String)
Text is truncated with a custom string at the end when it overflows