#[non_exhaustive]pub enum TextWrapMode {
Wrap,
NoWrap,
}Expand description
Controls whether text should be wrapped.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Wrap
Text is wrapped across lines at appropriate characters to minimize overflow.
NoWrap
Text does not wrap across lines. It will overflow its containing element rather than breaking onto a new line.