#[non_exhaustive]pub enum WordBreak {
Normal,
BreakAll,
KeepAll,
BreakWord,
}Expand description
Controls how text should be broken at word boundaries.
Corresponds to CSS word-break property.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal
Normal line breaking behavior—lines may break according to language rules.
BreakAll
Break words at arbitrary points to prevent overflow.
KeepAll
Prevents word breaks within words. Useful for languages like Japanese.
BreakWord
Allow breaking within long words if necessary to prevent overflow.