GridRepeatTrack

Struct GridRepeatTrack 

#[non_exhaustive]
pub struct GridRepeatTrack { pub size: GridTrackSize, pub names: Vec<String>, pub end_names: Option<Vec<String>>, }
Represents a grid repeat track

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
size: GridTrackSize

The size of the grid track

names: Vec<String>

The names for the line preceding this track within the repeat() clause

end_names: Option<Vec<String>>

The names for the final line after the last track within the repeat() clause Only set on the last track of the repeat fragment. For other tracks this is None.