#[non_exhaustive]pub struct InsetShape {
pub inset: Sides<Length>,
pub border_radius: Option<Sides<Length>>,
}Expand description
Represents an inset() rectangle shape.
The inset() function creates an inset rectangle, with its size defined by the offset distance of each of the four sides of its container and, optionally, rounded corners.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inset: Sides<Length>Sides of the inset.
border_radius: Option<Sides<Length>>Optional border radius for rounded corners