StyleDeclarationBlock

Struct StyleDeclarationBlock 

pub struct StyleDeclarationBlock {
    pub declarations: SmallVec<[StyleDeclaration; 8]>,
    pub importance: DeclarationImportance,
}
Ordered specified declarations plus the set of important properties.

Fields

declarations: SmallVec<[StyleDeclaration; 8]>

Ordered declarations in source order.

importance: DeclarationImportance

Properties that were marked with !important.

Implementations

Source

impl StyleDeclarationBlock

pub fn push(&mut self, declaration: StyleDeclaration, important: bool)

Appends a declaration and records whether it was important.

pub fn append(&mut self, other: Self)

pub fn iter(&self) -> Iter<'_, StyleDeclaration>

Iterates over the declarations in source order.

pub fn resource_urls(&self) -> impl Iterator<Item = &str>

Collects resource URLs referenced by declarations in this block.

pub fn parse<'i>( name: &str, input: &mut Parser<'i, '_>, ) -> ParseResult<'i, Self>