TextFit

Struct TextFit 

#[non_exhaustive]
pub struct TextFit { pub mode: TextFitMode, pub target: TextFitTarget, pub limit: Option<f32>, }
Controls whether inline contents are scaled to fit their line box.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
mode: TextFitMode

Selects whether fitting grows, shrinks, or leaves text unchanged.

target: TextFitTarget

Selects whether fitting uses one scale or per-line scales.

limit: Option<f32>

Optional scale clamp as a multiplier, parsed from a CSS percentage.

Implementations

Source

impl TextFit

pub fn builder() -> TextFitBuilder<((), (), ())>

Create a builder for building TextFit. On the builder, call .mode(...)(optional), .target(...)(optional), .limit(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of TextFit.