#[non_exhaustive]pub struct TextIndent {
pub amount: LengthDefaultsToZero,
pub each_line: bool,
pub hanging: bool,
}Expand description
Controls indentation of the first line, or hanging/each-line variants.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.amount: LengthDefaultsToZeroThe indent amount.
each_line: boolApply the indent after every hard line break.
hanging: boolIndent continuation lines instead of the first line.
Implementations
Sourceimpl TextIndent
impl TextIndent
Sourcepub const fn new(amount: LengthDefaultsToZero) -> Self
pub const fn new(amount: LengthDefaultsToZero) -> Self
Creates a text indent with the given amount and default keyword options.
Sourcepub const fn with_each_line(self, each_line: bool) -> Self
pub const fn with_each_line(self, each_line: bool) -> Self
Sets whether the indent also applies after explicit line breaks.
Sourcepub const fn with_hanging(self, hanging: bool) -> Self
pub const fn with_hanging(self, hanging: bool) -> Self
Sets whether continuation lines are indented instead of the first line.
pub fn resolve_px(self, sizing: &SizingContext, line_width: f32) -> f32