pub struct Transforms(pub Box<[Transform]>);Expand description
A collection of transform operations that can be applied together
Tuple Fields
0: Box<[Transform]>Trait Implementations
Sourceimpl Clone for Transforms
impl Clone for Transforms
Sourcefn clone(&self) -> Transforms
fn clone(&self) -> Transforms
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Transforms
impl Debug for Transforms
Sourceimpl Deref for Transforms
impl Deref for Transforms
Sourceimpl DerefMut for Transforms
impl DerefMut for Transforms
Sourceimpl<'i> FromCss<'i> for Transforms
impl<'i> FromCss<'i> for Transforms
Sourceconst VALID_TOKENS: &'static [CssToken] = Transform::VALID_TOKENS
const VALID_TOKENS: &'static [CssToken] = Transform::VALID_TOKENS
Returns the list of valid CSS tokens for this type.
Sourcefn from_css(input: &mut Parser<'i, '_>) -> ParseResult<'i, Self>
fn from_css(input: &mut Parser<'i, '_>) -> ParseResult<'i, Self>
Parses the type from a
Parser instance.Sourcefn from_str(source: &'i str) -> ParseResult<'i, Self>where
Self: Sized,
fn from_str(source: &'i str) -> ParseResult<'i, Self>where
Self: Sized,
Helper function to parse the type from a string.
Sourceconst EXPECT_MESSAGE: CssExpectedMessage = CssExpectedMessage::OneValue
const EXPECT_MESSAGE: CssExpectedMessage = CssExpectedMessage::OneValue
Message template used when building parse errors for this type.
Sourceimpl PartialEq for Transforms
impl PartialEq for Transforms
Sourcefn eq(&self, other: &Transforms) -> bool
fn eq(&self, other: &Transforms) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Transforms