pub type AnimationTimingFunctions = Box<[AnimationTimingFunction]>;Expand description
Parsed values for animation-timing-function.
Aliased Type
pub struct AnimationTimingFunctions(/* private fields */);Trait Implementations
Sourceimpl<'i> FromCss<'i> for AnimationTimingFunctions
impl<'i> FromCss<'i> for AnimationTimingFunctions
Sourceconst VALID_TOKENS: &'static [CssToken] = AnimationTimingFunction::VALID_TOKENS
const VALID_TOKENS: &'static [CssToken] = AnimationTimingFunction::VALID_TOKENS
Returns the list of valid CSS tokens for this type.
Sourcefn from_css(input: &mut Parser<'i, '_>) -> ParseResult<'i, Self>
fn from_css(input: &mut Parser<'i, '_>) -> ParseResult<'i, Self>
Parses the type from a
Parser instance.Sourcefn from_str(source: &'i str) -> ParseResult<'i, Self>where
Self: Sized,
fn from_str(source: &'i str) -> ParseResult<'i, Self>where
Self: Sized,
Helper function to parse the type from a string.
Sourceconst EXPECT_MESSAGE: CssExpectedMessage = CssExpectedMessage::OneValue
const EXPECT_MESSAGE: CssExpectedMessage = CssExpectedMessage::OneValue
Message template used when building parse errors for this type.