pub type BoxShadows = Box<[BoxShadow]>;Expand description
Represents a collection of box shadows, have custom FromCss implementation for comma-separated values.
Aliased Type
pub struct BoxShadows(/* private fields */);Trait Implementations
Sourceimpl<'i> FromCss<'i> for BoxShadows
impl<'i> FromCss<'i> for BoxShadows
Sourceconst VALID_TOKENS: &'static [CssToken] = BoxShadow::VALID_TOKENS
const VALID_TOKENS: &'static [CssToken] = BoxShadow::VALID_TOKENS
Returns the list of valid CSS tokens for this type.
Sourcefn from_css(input: &mut Parser<'i, '_>) -> ParseResult<'i, Self>
fn from_css(input: &mut Parser<'i, '_>) -> ParseResult<'i, Self>
Parses the type from a
Parser instance.Sourcefn from_str(source: &'i str) -> ParseResult<'i, Self>where
Self: Sized,
fn from_str(source: &'i str) -> ParseResult<'i, Self>where
Self: Sized,
Helper function to parse the type from a string.
Sourceconst EXPECT_MESSAGE: CssExpectedMessage = CssExpectedMessage::OneValue
const EXPECT_MESSAGE: CssExpectedMessage = CssExpectedMessage::OneValue
Message template used when building parse errors for this type.