#[non_exhaustive]pub enum BoxSizing {
ContentBox,
BorderBox,
}Expand description
Defines how the width and height of an element are calculated.
This enum determines whether the width and height properties include padding and border, or just the content area.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ContentBox
The width and height properties include padding and border, but not the content area
BorderBox
The width and height properties include the content area, but not padding and border