#[non_exhaustive]pub enum TextAlign {
Left,
Right,
Center,
Justify,
Start,
End,
}Expand description
Text alignment options for text rendering.
Corresponds to CSS text-align property values.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Left
Aligns inline content to the left edge of the line box
Right
Aligns inline content to the right edge of the line box
Center
Centers inline content within the line box
Justify
Expands inline content to fill the entire line box
Start
Aligns inline content to the start edge of the line box (language-dependent)
End
Aligns inline content to the end edge of the line box (language-dependent)