pub struct StyleDeclarationBlock {
pub declarations: SmallVec<[StyleDeclaration; 8]>,
pub importance: DeclarationImportance,
}Expand description
Ordered specified declarations plus the set of important properties.
Fields
declarations: SmallVec<[StyleDeclaration; 8]>Ordered declarations in source order.
importance: DeclarationImportanceProperties that were marked with !important.
Implementations
Sourceimpl StyleDeclarationBlock
impl StyleDeclarationBlock
Sourcepub fn push(&mut self, declaration: StyleDeclaration, important: bool)
pub fn push(&mut self, declaration: StyleDeclaration, important: bool)
Appends a declaration and records whether it was important.
pub fn append(&mut self, other: Self)
Sourcepub fn iter(&self) -> Iter<'_, StyleDeclaration>
pub fn iter(&self) -> Iter<'_, StyleDeclaration>
Iterates over the declarations in source order.
Sourcepub fn resource_urls(&self) -> impl Iterator<Item = &str>
pub fn resource_urls(&self) -> impl Iterator<Item = &str>
Collects resource URLs referenced by declarations in this block.
pub fn parse<'i>( name: &str, input: &mut Parser<'i, '_>, ) -> ParseResult<'i, Self>