#[non_exhaustive]pub struct TextFit {
pub mode: TextFitMode,
pub target: TextFitTarget,
pub limit: Option<f32>,
}Expand description
Controls whether inline contents are scaled to fit their line box.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: TextFitModeSelects whether fitting grows, shrinks, or leaves text unchanged.
target: TextFitTargetSelects whether fitting uses one scale or per-line scales.
limit: Option<f32>Optional scale clamp as a multiplier, parsed from a CSS percentage.
Implementations