pub type LengthDefaultsToZero = Length<false>;Expand description
A length value that defaults to zero instead of auto.
Aliased Type
pub enum LengthDefaultsToZero {
}Variants
Auto
Automatic sizing based on content
Percentage(f32)
Percentage value relative to parent container (0-100)
Rem(f32)
Rem value relative to the root font size
Em(f32)
Em value relative to the font size
Lh(f32)
Lh value relative to the element’s computed line-height
Rlh(f32)
Rlh value relative to the root element’s computed line-height
Vh(f32)
Vh value relative to the viewport height (0-100)
Vw(f32)
Vw value relative to the viewport width (0-100)
CqH(f32)
Cqh value relative to the query container height (0-100)
CqW(f32)
Cqw value relative to the query container width (0-100)
CqMin(f32)
Cqmin value relative to the query container smaller dimension (0-100)
CqMax(f32)
Cqmax value relative to the query container larger dimension (0-100)
VMin(f32)
Vmin value relative to the smaller viewport dimension (0-100)
VMax(f32)
Vmax value relative to the larger viewport dimension (0-100)
Cm(f32)
Centimeter value
Mm(f32)
Millimeter value
In(f32)
Inch value
Q(f32)
Quarter value
Pt(f32)
Point value
Pc(f32)
Picas value
Px(f32)
Specific pixel value
Calc(CalcFormula)
calc(…) expression